==> libamtrack_0.6.2.tar.gz: libamtrack/src/AT.h <==
#ifndef AT_H_
#define AT_H_

/**
 * @brief Routines concerning general topis of libamtrack
 */

/*
 *    AT.h
 *    ===============
 *
 *    Created on: 14.08.2011
 *    Creator: greilich
 *
 *    File name: $HeadURL: https://svn.code.sf.net/p/libamtrack/code/tags/0.6.2/include/AT.h $
 *    Revision:  $Revision: 1330 $
 *    Last modified: $Date: 2015-04-23 15:24:20 +0200 (Do, 23 Apr 2015) $
 *    Last modified by: $Author: sgreilich $
 *
 *    Copyright 2006, 2010 The libamtrack team
 *
 *    This file is part of the AmTrack program (libamtrack.sourceforge.net).
 *
 *    AmTrack is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    AmTrack is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with AmTrack (file: copying.txt).
 *    If not, see <http://www.gnu.org/licenses/>
 */

#include <stdio.h>



/**
 * Simple test function (sum) to check for availability and functionality of
 * libamtrack during configure-process
 *
 * @param[in]      a     			first number to add
 * @param[in]      b                second number to add
 * @return                          sum of a and b
 */
 double AT_test_fun( double a, double b);

 // Just a test
 
#endif /* AT_ALGORITHMS_CPP_H_ */

==> libamtrack_0.6.3.tar.gz: libamtrack/src/AT.h <==
#ifndef AT_H_
#define AT_H_

/**
 * @brief Routines concerning general topis of libamtrack
 */

/*
 *    AT.h
 *    ===============
 *
 *    Created on: 14.08.2011
 *    Creator: greilich
 *
 *    File name: $HeadURL$
 *    Revision:  $Revision$
 *    Last modified: $Date$
 *    Last modified by: $Author$
 *
 *    Copyright 2006, 2010 The libamtrack team
 *
 *    This file is part of the AmTrack program (libamtrack.sourceforge.net).
 *
 *    AmTrack is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    AmTrack is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with AmTrack (file: copying.txt).
 *    If not, see <http://www.gnu.org/licenses/>
 */

#include <stdio.h>



/**
 * Simple test function (sum) to check for availability and functionality of
 * libamtrack during configure-process
 *
 * @param[in]      a     			first number to add
 * @param[in]      b                second number to add
 * @return                          sum of a and b
 */
 double AT_test_fun( double a, double b);

 // Just a test
 
#endif /* AT_ALGORITHMS_CPP_H_ */
